@@ -26,7 +26,7 @@ def decode_tag(tag):
     name = base64url_decode(tag['name'].encode())
     value = base64url_decode(tag['value'].encode())
     
-    return name, value
+    return {'name':name, 'value':value}
 
 
 def owner_to_address(owner):
@@ -52,3 +52,22 @@ def ar_to_winston(ar_amount):
     ar_str = "{:.12f}".format(ar_amount)
     return ar_str.replace('.','').lstrip("0")
 
+
+def concat_buffers(buffers):
+    total_length = 0
+
+    for buffer in buffers:
+        total_length += len(buffer)
+
+    offset = 0
+
+    temp = b'\x00' * total_length
+    temp = bytearray(temp)
+    for buffer in buffers:
+        for i in range(len(buffer)):
+            temp[i + offset] = buffer[i]
+
+        offset += len(buffer)
+
+    return bytes(temp)
+
